@@ -296,14 +296,14 @@ void IncidenceDialogPrivate::loadTemplate(const QString &templateName)
 
     const QString fileName = QStandardPaths::locate(
                                  QStandardPaths::GenericDataLocation,
-                                 QStringLiteral("korganizer/templates/") +
+                                 QStringLiteral("/korganizer/templates/") +
                                  typeToString(mEditor->type()) + QLatin1Char('/') +
                                  templateName);
 
     if (fileName.isEmpty()) {
         KMessageBox::error(
             q,
-            i18nc("@info", "Unable to find template '%1'.", fileName));
+            i18nc("@info", "Unable to find template '%1'.", templateName));
         return;
     }
 
@@ -384,8 +384,8 @@ void IncidenceDialogPrivate::saveTemplate(const QString &templateName)
     }
 
     QString fileName = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +
-                       QStringLiteral("korganizer/templates/") + typeToString(mEditor->type()) + QLatin1Char('/');
-    QDir::root().mkpath(fileName);
+                       QStringLiteral("/korganizer/templates/") + typeToString(mEditor->type()) + QLatin1Char('/');
+    QDir().mkpath(fileName);
     fileName += templateName;
 
     KCalCore::ICalFormat format;
@@ -401,7 +401,7 @@ void IncidenceDialogPrivate::storeTemplatesInConfig(const QStringList &templateN
     const QString defaultPath = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) +
                                 QStringLiteral("korganizer/templates/") +
                                 typeToString(mEditor->type()) + QLatin1Char('/');
-    QDir::root().mkpath(defaultPath);
+    QDir().mkpath(defaultPath);
     for (const QString &tmpl : origTemplates) {
         if (!templateNames.contains(tmpl)) {
             const QString fileName = defaultPath + tmpl;
