@@ -159,7 +159,7 @@ void IncidenceRecurrence::load(const KCalCore::Incidence::Ptr &incidence)
     }
 
     int f = 0;
-    KCalCore::Recurrence *r = 0;
+    KCalCore::Recurrence *r = nullptr;
     if (mLoadedIncidence->recurrenceType() != KCalCore::Recurrence::rNone) {
         r = mLoadedIncidence->recurrence();
         f = r->frequency();
@@ -616,8 +616,8 @@ void IncidenceRecurrence::handleRecurrenceTypeChange(int currentIndex)
 
 void IncidenceRecurrence::removeExceptions()
 {
-    QList<QListWidgetItem *> selectedExceptions = mUi->mExceptionList->selectedItems();
-    foreach (QListWidgetItem *selectedException, selectedExceptions) {
+    const QList<QListWidgetItem *> selectedExceptions = mUi->mExceptionList->selectedItems();
+    for (QListWidgetItem *selectedException : selectedExceptions) {
         const int row = mUi->mExceptionList->row(selectedException);
         mExceptionDates.removeAt(row);
         delete mUi->mExceptionList->takeItem(row);
