@@ -109,7 +109,7 @@ public:
 ResourceManagement::ResourceManagement(QWidget *parent)
     : QDialog(parent)
 {
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Close, this);
     QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
     okButton->setDefault(true);
     okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
@@ -203,7 +203,7 @@ void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::
 {
     // Clean up formDetails
     QLayoutItem *child;
-    while ((child = mUi->formDetails->takeAt(0)) != 0) {
+    while ((child = mUi->formDetails->takeAt(0)) != nullptr) {
         delete child->widget();
         delete child;
     }
@@ -228,10 +228,10 @@ void ResourceManagement::showDetails(const KLDAP::LdapObject &obj, const KLDAP::
         QStringList list;
         const QList<QByteArray> values = it.value();
         list.reserve(values.count());
-        foreach (const QByteArray &value, values) {
+        for (const QByteArray &value: values) {
             list << QString::fromUtf8(value);
         }
-        mUi->formDetails->addRow(translateLDAPAttributeForDisplay(key), new QLabel(list.join(QStringLiteral("\n"))));
+        mUi->formDetails->addRow(translateLDAPAttributeForDisplay(key), new QLabel(list.join(QLatin1Char('\n'))));
     }
 
     QString name = QString::fromUtf8(obj.attributes().value(QStringLiteral("cn"))[0]);
@@ -254,7 +254,7 @@ void ResourceManagement::slotOwnerSearchFinished()
 {
     // Clean up formDetails
     QLayoutItem *child;
-    while ((child = mUi->formOwner->takeAt(0)) != 0) {
+    while ((child = mUi->formOwner->takeAt(0)) != nullptr) {
         delete child->widget();
         delete child;
     }
@@ -273,10 +273,10 @@ void ResourceManagement::slotOwnerSearchFinished()
         QStringList list;
         const QList<QByteArray> values = it.value();
         list.reserve(values.count());
-        foreach (const QByteArray &value, values) {
+        for (const QByteArray &value : values) {
             list << QString::fromUtf8(value);
         }
-        mUi->formOwner->addRow(translateLDAPAttributeForDisplay(key), new QLabel(list.join(QStringLiteral("\n"))));
+        mUi->formOwner->addRow(translateLDAPAttributeForDisplay(key), new QLabel(list.join(QLatin1Char('\n'))));
     }
 }
 
